@@ -43,7 +43,9 @@ private:
 
   // allocate()
   static Rcpp::RObject class_from_datatype(DATA_TYPE dt);
-  static void set_attribs_from_datatype(SEXP x, DATA_TYPE dt);
+  static SEXP set_attribs_from_datatype(SEXP x, DATA_TYPE dt);
+  static SEXP new_blob(SEXP x);
+  static SEXP new_hms(SEXP x);
 
   // copy_to()
   static void fill_default_value(SEXP data, DATA_TYPE dt, R_xlen_t i);
