@@ -6,9 +6,9 @@
 
 
 // [[Rcpp::export]]
-XPtr<DbResult> result_create(XPtr<DbConnectionPtr> con, std::string sql, bool is_statement = false) {
+XPtr<DbResult> result_create(XPtr<DbConnectionPtr> con, std::string sql) {
   (*con)->check_connection();
-  DbResult* res = DbResult::create_and_send_query(*con, sql, is_statement);
+  DbResult* res = SqliteResult::create_and_send_query(*con, sql);
   return XPtr<DbResult>(res, true);
 }
 
@@ -54,7 +54,7 @@ List result_column_info(DbResult* res) {
 }
 
 // [[Rcpp::export]]
-CharacterVector result_get_placeholder_names(DbResult* res) {
+CharacterVector result_get_placeholder_names(SqliteResult* res) {
   return res->get_placeholder_names();
 }
 
@@ -68,4 +68,12 @@ DbResult* as(SEXP x) {
   return result;
 }
 
+template<>
+SqliteResult* as(SEXP x) {
+  SqliteResult* result = (SqliteResult*)(R_ExternalPtrAddr(x));
+  if (!result)
+    stop("Invalid result set");
+  return result;
+}
+
 }
